@@ -20,11 +20,31 @@ use Sim::OPT;
 use Sim::OPT::Morph;
 use Sim::OPT::Sim;
 use Sim::OPT::Report;
-use Sim::OPT::Interlinear;
+
 use Sim::OPT::Takechance;
+use Sim::OPT::Interlinear;
 use Sim::OPT::Parcoord3d;
 use Sim::OPT::Stats;
 eval { use Sim::OPTcue::OPTcue; 1 };
+eval { use Sim::OPTcue::Metabridge; 1 };
+eval { use Sim::OPTcue::Exogen::PatternSearch; 1 };
+eval { use Sim::OPTcue::Exogen::NelderMead; 1 };
+eval { use Sim::OPTcue::Exogen::Armijo; 1 };
+eval { use Sim::OPTcue::Exogen::NSGAII; 1 };
+eval { use Sim::OPTcue::Exogen::ParticleSwarm; 1 };
+eval { use Sim::OPTcue::Exogen::SimulatedAnnealing; 1 };
+eval { use Sim::OPTcue::Exogen::NSGAIII; 1 };
+eval { use Sim::OPTcue::Exogen::MOEAD; 1 };
+eval { use Sim::OPTcue::Exogen::SPEA2; 1 };
+eval { use Sim::OPTcue::Exogen::ParticleSwarm; 1 };
+eval { use Sim::OPTcue::Exogen::RadialBasis; 1 };
+eval { use Sim::OPTcue::Exogen::Kriging; 1 };
+eval { use Sim::OPTcue::Exogen::DecisionTree; 1 };
+eval { use Sim::OPTcue::Exogen::KNN; 1 };
+eval { use Sim::OPTcue::Exogen::FFNN; 1 };
+eval { use Sim::OPTcue::Exogen::GBDT; 1 };
+eval { use Sim::OPTcue::Endogen::DWGN2; 1 };
+eval { use Sim::OPTcue::Endogen::NeuralBoltzmann; 1 };
 
 
 $Data::Dumper::Indent = 0;
@@ -161,7 +181,7 @@ sub descend
   my %dowhat = %{ $dt{dowhat} };
   #my $csim = $dt{csim}; #UNUSED
   my $precious = $dt{precious};
-  my @packet = @{ $dt{packet} }; say  "HERE IN DESCEND \@packet: " . dump( @packet );
+  my @packet = @{ $dt{packet} }; #say  "HERE IN DESCEND \@packet: " . dump( @packet );
 
   my $exitname = $dirfiles{exitname};
 
@@ -169,7 +189,7 @@ sub descend
 
   my %d = %{ $instances[0] };
   my $countcase = $d{countcase}; #say  "HERE IN DESCEND \$countcase: " . dump( $countcase );
-  my $countblock = $d{countblock}; say  "HERE IN DESCEND \$countblock: " . dump( $countblock );
+  my $countblock = $d{countblock}; #say  "HERE IN DESCEND \$countblock: " . dump( $countblock );
   my %incumbents = %{ $d{incumbents} }; #say  "HERE IN DESCEND \%incumbents: " . dump( \%incumbents );
   my @varnumbers = @{ $d{varnumbers} };
   @varnumbers = Sim::OPT::washn( @varnumbers ); #say  "HERE IN DESCEND \@varnumbers: " . dump( @varnumbers );
@@ -292,8 +312,11 @@ sub descend
 
   my $confinterlinear = "$mypath/" . $dowhat{confinterlinear} ;
 
-  
-  my $repfile = $dirfiles{repfile}; say  "IN DESCENT FROM DIRFILES, \$countblock $countblock, \$repfile $repfile";
+  if ( !$dirfiles{repfile} )
+  {
+    $dirfiles{repfile} = "$mypath/$file-report-$countcase-$countblock.csv";
+  }
+  my $repfile = $dirfiles{repfile}; #say  "IN DESCENT FROM DIRFILES, \$countblock $countblock, \$repfile $repfile";
 
   if ( $fire eq "y" )
   {
@@ -361,7 +384,7 @@ sub descend
   #  sourcesweeps => \@sourcesweeps, instn => $instn, inst => \%inst, vehicles => \%vehicles } );
   #}
 
-  #say  "!!!!IN DESCEND \$repfile " . dump($repfile);
+
   if ( ( $dowhat{dumpfiles} eq "y" ) and ( not( -e $repfile ) ) )
   { die "There isn't \$repfile: $repfile"; };
 
